package java.awt;

import java.io.Serializable;

public class BorderLayout implements LayoutManager2, Serializable {
   int hgap;
   int vgap;
   Component north;
   Component west;
   Component east;
   Component south;
   Component center;
   public static final String NORTH = "North";
   public static final String SOUTH = "South";
   public static final String EAST = "East";
   public static final String WEST = "West";
   public static final String CENTER = "Center";
   private static final long serialVersionUID = -8658291919501921765L;

   public BorderLayout() {
      this(0, 0);
   }

   public BorderLayout(int var1, int var2) {
      this.hgap = var1;
      this.vgap = var2;
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(Component var1, Object var2) {
      if (var2 != null && !(var2 instanceof String)) {
         throw new IllegalArgumentException("cannot add to layout: constraint must be a string (or null)");
      } else {
         this.addLayoutComponent((String)var2, var1);
      }
   }

   public void addLayoutComponent(String var1, Component var2) {
      if (var1 == null) {
         var1 = "Center";
      }

      if ("Center".equals(var1)) {
         this.center = var2;
      } else if ("North".equals(var1)) {
         this.north = var2;
      } else if ("South".equals(var1)) {
         this.south = var2;
      } else if ("East".equals(var1)) {
         this.east = var2;
      } else if ("West".equals(var1)) {
         this.west = var2;
      } else {
         throw new IllegalArgumentException("cannot add to layout: unknown constraint: " + var1);
      }
   }

   public void removeLayoutComponent(Component var1) {
      if (var1 == this.center) {
         this.center = null;
      } else if (var1 == this.north) {
         this.north = null;
      } else if (var1 == this.south) {
         this.south = null;
      } else if (var1 == this.east) {
         this.east = null;
      } else {
         if (var1 == this.west) {
            this.west = null;
         }

      }
   }

   public Dimension minimumLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      if (this.east != null && this.east.visible) {
         Dimension var3 = this.east.getMinimumSize();
         var2.width += var3.width + this.hgap;
         var2.height = Math.max(var3.height, var2.height);
      }

      if (this.west != null && this.west.visible) {
         Dimension var4 = this.west.getMinimumSize();
         var2.width += var4.width + this.hgap;
         var2.height = Math.max(var4.height, var2.height);
      }

      if (this.center != null && this.center.visible) {
         Dimension var5 = this.center.getMinimumSize();
         var2.width += var5.width;
         var2.height = Math.max(var5.height, var2.height);
      }

      if (this.north != null && this.north.visible) {
         Dimension var6 = this.north.getMinimumSize();
         var2.width = Math.max(var6.width, var2.width);
         var2.height += var6.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         Dimension var7 = this.south.getMinimumSize();
         var2.width = Math.max(var7.width, var2.width);
         var2.height += var7.height + this.vgap;
      }

      Insets var8 = var1.getInsets();
      var2.width += var8.left + var8.right;
      var2.height += var8.top + var8.bottom;
      return var2;
   }

   public Dimension preferredLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      if (this.east != null && this.east.visible) {
         Dimension var3 = this.east.getPreferredSize();
         var2.width += var3.width + this.hgap;
         var2.height = Math.max(var3.height, var2.height);
      }

      if (this.west != null && this.west.visible) {
         Dimension var4 = this.west.getPreferredSize();
         var2.width += var4.width + this.hgap;
         var2.height = Math.max(var4.height, var2.height);
      }

      if (this.center != null && this.center.visible) {
         Dimension var5 = this.center.getPreferredSize();
         var2.width += var5.width;
         var2.height = Math.max(var5.height, var2.height);
      }

      if (this.north != null && this.north.visible) {
         Dimension var6 = this.north.getPreferredSize();
         var2.width = Math.max(var6.width, var2.width);
         var2.height += var6.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         Dimension var7 = this.south.getPreferredSize();
         var2.width = Math.max(var7.width, var2.width);
         var2.height += var7.height + this.vgap;
      }

      Insets var8 = var1.getInsets();
      var2.width += var8.left + var8.right;
      var2.height += var8.top + var8.bottom;
      return var2;
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      Insets var2 = var1.getInsets();
      int var3 = var2.top;
      int var4 = var1.height - var2.bottom;
      int var5 = var2.left;
      int var6 = var1.width - var2.right;
      if (this.north != null && this.north.visible) {
         this.north.setSize(var6 - var5, this.north.height);
         Dimension var7 = this.north.getPreferredSize();
         this.north.setBounds(var5, var3, var6 - var5, var7.height);
         var3 += var7.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         this.south.setSize(var6 - var5, this.south.height);
         Dimension var8 = this.south.getPreferredSize();
         this.south.setBounds(var5, var4 - var8.height, var6 - var5, var8.height);
         var4 -= var8.height + this.vgap;
      }

      if (this.east != null && this.east.visible) {
         this.east.setSize(this.east.width, var4 - var3);
         Dimension var9 = this.east.getPreferredSize();
         this.east.setBounds(var6 - var9.width, var3, var9.width, var4 - var3);
         var6 -= var9.width + this.hgap;
      }

      if (this.west != null && this.west.visible) {
         this.west.setSize(this.west.width, var4 - var3);
         Dimension var10 = this.west.getPreferredSize();
         this.west.setBounds(var5, var3, var10.width, var4 - var3);
         var5 += var10.width + this.hgap;
      }

      if (this.center != null && this.center.visible) {
         this.center.setBounds(var5, var3, var6 - var5, var4 - var3);
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + "]";
   }
}
