package java.awt;

import java.awt.peer.DialogPeer;
import java.util.Enumeration;
import java.util.Vector;
import sun.awt.SunToolkit;

public class Dialog extends Window {
   boolean resizable;
   boolean modal;
   String title;
   private static final String base = "dialog";
   private static int nameCounter;
   private static final long serialVersionUID = 5920926903803293709L;
   private Vector m_disabledWindows;
   private Dialog m_previousModalDialog;

   public Dialog(Frame var1) {
      this(var1, "", false);
   }

   public Dialog(Frame var1, boolean var2) {
      this(var1, "", var2);
   }

   public Dialog(Frame var1, String var2) {
      this(var1, var2, false);
   }

   public Dialog(Frame var1, String var2, boolean var3) {
      super(var1);
      this.resizable = true;
      if (var1 == null) {
         throw new IllegalArgumentException("null parent frame");
      } else {
         super.name = "dialog" + nameCounter++;
         this.title = var2;
         this.modal = var3;
      }
   }

   public void addNotify() {
      if (super.peer == null) {
         super.peer = ((Window)this).getToolkit().createDialog(this);
      }

      super.addNotify();
   }

   public boolean isModal() {
      return this.modal;
   }

   public void setModal(boolean var1) {
      this.modal = var1;
   }

   public String getTitle() {
      return this.title;
   }

   public synchronized void setTitle(String var1) {
      this.title = var1;
      DialogPeer var2 = (DialogPeer)super.peer;
      if (var2 != null) {
         var2.setTitle(var1);
      }

   }

   public void show() {
      super.show();
   }

   protected void __showDialog() {
      Object var1 = Component.LOCK;
      synchronized(var1){}

      try {
         if (super.parent != null && super.parent.getPeer() == null) {
            super.parent.addNotify();
         }

         if (super.peer == null) {
            this.addNotify();
            Dimension var3 = ((Container)this).getMinimumSize();
            if (var3.width > super.width || var3.height > super.height) {
               ((Component)this).setSize(var3);
            }
         }

         ((Container)this).validate();
      } catch (Throwable var5) {
         throw var5;
      }

      if (super.visible) {
         ((Window)this).toFront();
      } else {
         super.visible = true;
         if (this.isModal()) {
            Window[] var6 = SunToolkit.getTopLevelWindows();
            if (var6 == null) {
               Frame var2 = (Frame)((Component)this).getParent();
               int var8 = var2.ownedWindows.size() + 1;
               var6 = new Window[var8];
               var2.ownedWindows.copyInto(var6);
               var6[var8 - 1] = var2;
            }

            this.m_disabledWindows = new Vector(var6.length);

            for(int var7 = 0; var7 < var6.length; ++var7) {
               Window var9 = var6[var7];
               if (var9 != this && ((Component)var9).isVisible() && ((Component)var9).isEnabled()) {
                  this.m_disabledWindows.addElement(var9);
                  var9.enabled = false;
                  ((Component)var9).getPeer().setEnabled(false);
               }
            }

            this.m_previousModalDialog = SunToolkit.swapTopModalDialog(this);
         }

         super.peer.show();
      }
   }

   void __hideDialog() {
      if (super.visible) {
         if (this.isModal()) {
            if (this.m_disabledWindows == null) {
               return;
            }

            Dialog var1 = SunToolkit.swapTopModalDialog(this.m_previousModalDialog);
            if (var1 != this) {
               System.out.println("java.awt.Dialog.__hideDialog(): self != this (self = " + var1 + "; this = " + this + ")");
            }

            if (this.m_previousModalDialog != null) {
               this.m_previousModalDialog.toFront();
            }

            Enumeration var2 = this.m_disabledWindows.elements();

            while(var2.hasMoreElements()) {
               Window var3 = (Window)var2.nextElement();
               var3.enabled = true;
               ((Component)var3).getPeer().setEnabled(true);
            }
         }

      }
   }

   public boolean isResizable() {
      return this.resizable;
   }

   public synchronized void setResizable(boolean var1) {
      this.resizable = var1;
      DialogPeer var2 = (DialogPeer)super.peer;
      if (var2 != null) {
         var2.setResizable(var1);
      }

   }

   protected String paramString() {
      String var1 = super.paramString() + (this.modal ? ",modal" : ",modeless");
      if (this.title != null) {
         var1 = var1 + ",title=" + this.title;
      }

      return var1;
   }
}
