package java.awt;

import java.io.Serializable;

class FocusManager implements Serializable {
   Container focusRoot;
   Component focusOwner;
   static final long serialVersionUID = 2491878825643557906L;

   FocusManager(Container var1) {
      this.focusRoot = var1;
   }

   void activateFocus() {
      boolean var1 = false;
      if (this.focusOwner != null) {
         if (!(var1 = this.assignFocus(this.focusOwner, false))) {
            var1 = this.focusNext(this.focusOwner);
         }
      } else {
         var1 = this.focusForward(this.focusRoot);
      }

      if (!var1) {
         this.focusRoot.requestFocus();
      }

   }

   synchronized void setFocusOwner(Component var1) {
      this.focusOwner = var1;
   }

   Component getFocusOwner() {
      return this.focusOwner;
   }

   boolean focusNext() {
      return this.focusNext(this.focusOwner);
   }

   boolean focusNext(Component var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      boolean var13;
      try {
         Object var5 = var1;
         Container var7;
         if (var1 != null && var1.parent != null) {
            do {
               boolean var6 = false;
               var7 = ((Component)var5).parent;

               for(int var9 = 0; var9 < var7.ncomponents; ++var9) {
                  Component var8 = var7.component[var9];
                  if (var6) {
                     if (this.assignFocus(var8)) {
                        var13 = true;
                        return var13;
                     }

                     if (var8 instanceof Container && var8.isVisible() && var8.isEnabled() && this.focusForward((Container)var8)) {
                        var13 = true;
                        return var13;
                     }
                  } else if (var8 == var5) {
                     var6 = true;
                  }
               }

               var5 = var7;
            } while(var7 != this.focusRoot && var7.parent != null);
         }

         if (!this.focusForward(this.focusRoot)) {
            var13 = false;
            return var13;
         }

         var13 = true;
      } catch (Throwable var11) {
         throw var11;
      }

      return var13;
   }

   boolean focusPrevious() {
      return this.focusPrevious(this.focusOwner);
   }

   boolean focusPrevious(Component var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      boolean var13;
      try {
         Object var5 = var1;
         Container var7;
         if (var1 != null && var1.parent != null) {
            do {
               boolean var6 = false;
               var7 = ((Component)var5).parent;

               for(int var9 = var7.ncomponents - 1; var9 >= 0; --var9) {
                  Component var8 = var7.component[var9];
                  if (var6) {
                     if (this.assignFocus(var8)) {
                        var13 = true;
                        return var13;
                     }

                     if (var8 instanceof Container && var8.isVisible() && var8.isEnabled() && this.focusBackward((Container)var8)) {
                        var13 = true;
                        return var13;
                     }
                  } else if (var8 == var5) {
                     var6 = true;
                  }
               }

               var5 = var7;
            } while(var7 != this.focusRoot);
         }

         if (!this.focusBackward(this.focusRoot)) {
            var13 = false;
            return var13;
         }

         var13 = true;
      } catch (Throwable var11) {
         throw var11;
      }

      return var13;
   }

   boolean assignFocus(Component var1) {
      return this.assignFocus(var1, true);
   }

   synchronized boolean assignFocus(Component var1, boolean var2) {
      if (!var1.isVisible() || !var1.isEnabled() || var2 && !var1.isFocusTraversable()) {
         return false;
      } else {
         var1.requestFocus();
         return true;
      }
   }

   synchronized boolean focusForward(Container var1) {
      for(int var2 = 0; var2 < var1.ncomponents; ++var2) {
         Component var3 = var1.component[var2];
         if (this.assignFocus(var3)) {
            return true;
         }

         if (var3 instanceof Container && var3.isVisible() && var3.isEnabled() && this.focusForward((Container)var3)) {
            return true;
         }
      }

      return false;
   }

   synchronized boolean focusBackward(Container var1) {
      for(int var2 = var1.ncomponents - 1; var2 >= 0; --var2) {
         Component var3 = var1.component[var2];
         if (this.assignFocus(var3)) {
            return true;
         }

         if (var3 instanceof Container && var3.isVisible() && var3.isEnabled() && this.focusBackward((Container)var3)) {
            return true;
         }
      }

      return false;
   }
}
