package java.awt;

import java.io.Serializable;

public class GridLayout implements LayoutManager, Serializable {
   int hgap;
   int vgap;
   int rows;
   int cols;

   public GridLayout() {
      this(1, 0, 0, 0);
   }

   public GridLayout(int var1, int var2) {
      this(var1, var2, 0, 0);
   }

   public GridLayout(int var1, int var2, int var3, int var4) {
      if (var1 == 0 && var2 == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.rows = var1;
         this.cols = var2;
         this.hgap = var3;
         this.vgap = var4;
      }
   }

   public int getRows() {
      return this.rows;
   }

   public void setRows(int var1) {
      if (var1 == 0 && this.cols == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.rows = var1;
      }
   }

   public int getColumns() {
      return this.cols;
   }

   public void setColumns(int var1) {
      if (var1 == 0 && this.rows == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.cols = var1;
      }
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      Insets var2 = var1.getInsets();
      int var3 = var1.getComponentCount();
      int var4 = this.rows;
      int var5 = this.cols;
      if (var4 > 0) {
         var5 = (var3 + var4 - 1) / var4;
      } else {
         var4 = (var3 + var5 - 1) / var5;
      }

      int var6 = 0;
      int var7 = 0;

      for(int var8 = 0; var8 < var3; ++var8) {
         Component var9 = var1.getComponent(var8);
         Dimension var10 = var9.getPreferredSize();
         if (var6 < var10.width) {
            var6 = var10.width;
         }

         if (var7 < var10.height) {
            var7 = var10.height;
         }
      }

      return new Dimension(var2.left + var2.right + var5 * var6 + (var5 - 1) * this.hgap, var2.top + var2.bottom + var4 * var7 + (var4 - 1) * this.vgap);
   }

   public Dimension minimumLayoutSize(Container var1) {
      Insets var2 = var1.getInsets();
      int var3 = var1.getComponentCount();
      int var4 = this.rows;
      int var5 = this.cols;
      if (var4 > 0) {
         var5 = (var3 + var4 - 1) / var4;
      } else {
         var4 = (var3 + var5 - 1) / var5;
      }

      int var6 = 0;
      int var7 = 0;

      for(int var8 = 0; var8 < var3; ++var8) {
         Component var9 = var1.getComponent(var8);
         Dimension var10 = var9.getMinimumSize();
         if (var6 < var10.width) {
            var6 = var10.width;
         }

         if (var7 < var10.height) {
            var7 = var10.height;
         }
      }

      return new Dimension(var2.left + var2.right + var5 * var6 + (var5 - 1) * this.hgap, var2.top + var2.bottom + var4 * var7 + (var4 - 1) * this.vgap);
   }

   public void layoutContainer(Container var1) {
      Insets var2 = var1.getInsets();
      int var3 = var1.getComponentCount();
      int var4 = this.rows;
      int var5 = this.cols;
      if (var3 != 0) {
         if (var4 > 0) {
            var5 = (var3 + var4 - 1) / var4;
         } else {
            var4 = (var3 + var5 - 1) / var5;
         }

         int var6 = var1.width - (var2.left + var2.right);
         int var7 = var1.height - (var2.top + var2.bottom);
         var6 = (var6 - (var5 - 1) * this.hgap) / var5;
         var7 = (var7 - (var4 - 1) * this.vgap) / var4;
         int var8 = 0;

         for(int var9 = var2.left; var8 < var5; var9 += var6 + this.hgap) {
            int var10 = 0;

            for(int var11 = var2.top; var10 < var4; var11 += var7 + this.vgap) {
               int var12 = var10 * var5 + var8;
               if (var12 < var3) {
                  var1.getComponent(var12).setBounds(var9, var11, var6, var7);
               }

               ++var10;
            }

            ++var8;
         }

      }
   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + ",rows=" + this.rows + ",cols=" + this.cols + "]";
   }
}
