package java.awt;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.peer.TextFieldPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

public class TextField extends TextComponent {
   int columns;
   char echoChar;
   transient ActionListener actionListener;
   private static final String base = "textfield";
   private static int nameCounter;
   private static final long serialVersionUID = -2966288784432217853L;
   private int textFieldSerializedDataVersion;

   public TextField() {
      this("", 0);
   }

   public TextField(String var1) {
      this(var1, var1.length());
   }

   public TextField(int var1) {
      this("", var1);
   }

   public TextField(String var1, int var2) {
      super(var1);
      this.textFieldSerializedDataVersion = 1;
      super.name = "textfield" + nameCounter++;
      this.columns = var2;
   }

   public void addNotify() {
      if (super.peer == null) {
         super.peer = ((Component)this).getToolkit().createTextField(this);
      }

      super.addNotify();
   }

   public char getEchoChar() {
      return this.echoChar;
   }

   public void setEchoChar(char var1) {
      this.setEchoCharacter(var1);
   }

   public void setEchoCharacter(char var1) {
      this.echoChar = var1;
      TextFieldPeer var2 = (TextFieldPeer)super.peer;
      if (var2 != null) {
         var2.setEchoCharacter(var1);
      }

   }

   public boolean echoCharIsSet() {
      return this.echoChar != 0;
   }

   public int getColumns() {
      return this.columns;
   }

   public void setColumns(int var1) {
      int var2 = this.columns;
      if (var1 < 0) {
         throw new IllegalArgumentException("columns less than zero.");
      } else {
         if (var1 != var2) {
            this.columns = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public Dimension getPreferredSize(int var1) {
      return this.preferredSize(var1);
   }

   public Dimension preferredSize(int var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      Dimension var2;
      try {
         TextFieldPeer var5 = (TextFieldPeer)super.peer;
         var2 = var5 != null ? var5.preferredSize(var1) : super.preferredSize();
      } catch (Throwable var7) {
         throw var7;
      }

      return var2;
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      Dimension var1;
      try {
         var1 = this.columns > 0 ? this.preferredSize(this.columns) : super.preferredSize();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public Dimension getMinimumSize(int var1) {
      return this.minimumSize(var1);
   }

   public Dimension minimumSize(int var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      Dimension var2;
      try {
         TextFieldPeer var5 = (TextFieldPeer)super.peer;
         var2 = var5 != null ? var5.minimumSize(var1) : super.minimumSize();
      } catch (Throwable var7) {
         throw var7;
      }

      return var2;
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      Dimension var1;
      try {
         var1 = this.columns > 0 ? this.minimumSize(this.columns) : super.minimumSize();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public synchronized void addActionListener(ActionListener var1) {
      this.actionListener = AWTEventMulticaster.add(this.actionListener, var1);
      super.newEventsOnly = true;
   }

   public synchronized void removeActionListener(ActionListener var1) {
      this.actionListener = AWTEventMulticaster.remove(this.actionListener, var1);
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 1001) {
         return (super.eventMask & 128L) != 0L || this.actionListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ActionEvent) {
         this.processActionEvent((ActionEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processActionEvent(ActionEvent var1) {
      if (this.actionListener != null) {
         this.actionListener.actionPerformed(var1);
      }

   }

   protected String paramString() {
      String var1 = super.paramString();
      if (this.echoChar != 0) {
         var1 = var1 + ",echo=" + this.echoChar;
      }

      return var1;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "actionL", this.actionListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while((var2 = var1.readObject()) != null) {
         String var3 = ((String)var2).intern();
         if (var3 == "actionL") {
            this.addActionListener((ActionListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }
}
