package java.awt;

import java.awt.event.ActionEvent;
import java.awt.peer.MenuComponentPeer;
import java.io.Serializable;

public abstract class MenuComponent implements Serializable {
   transient MenuComponentPeer peer;
   transient MenuContainer parent;
   Font font;
   String name;
   boolean newEventsOnly = false;
   static final String actionListenerK = "actionL";
   static final String itemListenerK = "itemL";
   private static final long serialVersionUID = -4536902356223894379L;

   public String getName() {
      return this.name;
   }

   public void setName(String var1) {
      this.name = var1;
   }

   public MenuContainer getParent() {
      return this.parent;
   }

   public MenuComponentPeer getPeer() {
      return this.peer;
   }

   public Font getFont() {
      Font var1 = this.font;
      if (var1 != null) {
         return var1;
      } else {
         MenuContainer var2 = this.parent;
         return var2 != null ? var2.getFont() : null;
      }
   }

   public void setFont(Font var1) {
      this.font = var1;
   }

   public void removeNotify() {
      MenuComponentPeer var1 = this.peer;
      if (var1 != null) {
         this.peer = null;
         var1.dispose();
      }

   }

   public boolean postEvent(Event var1) {
      MenuContainer var2 = this.parent;
      if (var2 != null) {
         var2.postEvent(var1);
      }

      return false;
   }

   public final void dispatchEvent(AWTEvent var1) {
      this.dispatchEventImpl(var1);
   }

   void dispatchEventImpl(AWTEvent var1) {
      if (this.newEventsOnly || this.parent != null && this.parent instanceof MenuComponent && ((MenuComponent)this.parent).newEventsOnly) {
         if (this.eventEnabled(var1)) {
            this.processEvent(var1);
            return;
         }

         if (var1 instanceof ActionEvent && this.parent != null) {
            ((MenuComponent)this.parent).dispatchEvent(new ActionEvent(this.parent, var1.getID(), ((ActionEvent)var1).getActionCommand()));
            return;
         }
      } else {
         Event var2 = var1.convertToOld();
         if (var2 != null) {
            this.postEvent(var2);
         }
      }

   }

   boolean eventEnabled(AWTEvent var1) {
      return false;
   }

   protected void processEvent(AWTEvent var1) {
   }

   protected String paramString() {
      return this.name != null ? this.name : "";
   }

   public String toString() {
      return this.getClass().getName() + "[" + this.paramString() + "]";
   }
}
